@@ -1,14 +1,13 @@
 package MooseX::Storage::Deferred;
-{
-  $MooseX::Storage::Deferred::VERSION = '0.44';
-}
 BEGIN {
   $MooseX::Storage::Deferred::AUTHORITY = 'cpan:STEVAN';
 }
-# ABSTRACT: A role for undecisive programmers
+# ABSTRACT: A role for indecisive programmers
+$MooseX::Storage::Deferred::VERSION = '0.46';
 use Moose::Role;
-
 with 'MooseX::Storage::Basic';
+use Carp 'confess';
+use namespace::autoclean;
 
 sub __get_method {
     my ( $self, $basename, $value, $method_name ) = @_;
@@ -72,18 +71,18 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Plunien Jonathan Rockway Yu Jos Boumans Karen Etheridge
-Ricardo SIGNES Signes Robert Boone Shawn M Moore Tomas Doran (t0m) Yuval
-Cory Kogman t0m Watson Dagfinn Ilmari Mannsåker Florian Ragwitz Johannes
-undecisive JSONpm
+Interactive, Inc. Golden Steinbrunner Florian Ragwitz Johannes Plunien
+Jonathan Rockway Yu Jos Boumans Karen Etheridge Ricardo Signes Robert Boone
+Shawn M Moore Cory Tomas Doran Yuval Kogman Watson Dagfinn Ilmari Mannsåker
+Dan Brook David JSONpm
 
 =head1 NAME
 
-MooseX::Storage::Deferred - A role for undecisive programmers
+MooseX::Storage::Deferred - A role for indecisive programmers
 
 =head1 VERSION
 
-version 0.44
+version 0.46
 
 =head1 SYNOPSIS
 
