@@ -1,14 +1,13 @@
 package MooseX::Storage::Engine::IO::File;
-{
-  $MooseX::Storage::Engine::IO::File::VERSION = '0.44';
-}
 BEGIN {
   $MooseX::Storage::Engine::IO::File::AUTHORITY = 'cpan:STEVAN';
 }
-# ABSTRACT: The actually file storage mechanism.
+# ABSTRACT: The actual file storage mechanism.
+$MooseX::Storage::Engine::IO::File::VERSION = '0.46';
 use Moose;
-
 use IO::File;
+use Carp 'confess';
+use namespace::autoclean;
 
 has 'file' => (
     is       => 'ro',
@@ -40,17 +39,15 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Plunien Jonathan Rockway Yu Jos Boumans Karen Etheridge
-Ricardo SIGNES Signes Robert Boone Shawn M Moore Tomas Doran (t0m) Yuval
-Cory Kogman t0m Watson Dagfinn Ilmari Mannsåker Florian Ragwitz Johannes
+Interactive, Inc.
 
 =head1 NAME
 
-MooseX::Storage::Engine::IO::File - The actually file storage mechanism.
+MooseX::Storage::Engine::IO::File - The actual file storage mechanism.
 
 =head1 VERSION
 
-version 0.44
+version 0.46
 
 =head1 DESCRIPTION
 
