@@ -1,14 +1,12 @@
 package MooseX::Storage::IO::AtomicFile;
-{
-  $MooseX::Storage::IO::AtomicFile::VERSION = '0.44';
-}
 BEGIN {
   $MooseX::Storage::IO::AtomicFile::AUTHORITY = 'cpan:STEVAN';
 }
 # ABSTRACT: An Atomic File I/O role
+$MooseX::Storage::IO::AtomicFile::VERSION = '0.46';
 use Moose::Role;
-
 use MooseX::Storage::Engine::IO::AtomicFile;
+use namespace::autoclean;
 
 with 'MooseX::Storage::IO::File';
 
@@ -28,9 +26,10 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Plunien Jonathan Rockway Yu Jos Boumans Karen Etheridge
-Ricardo SIGNES Signes Robert Boone Shawn M Moore Tomas Doran (t0m) Yuval
-Cory Kogman t0m Watson Dagfinn Ilmari Mannsåker Florian Ragwitz Johannes
+Interactive, Inc. Golden Steinbrunner Florian Ragwitz Johannes Plunien
+Jonathan Rockway Yu Jos Boumans Karen Etheridge Ricardo Signes Robert Boone
+Shawn M Moore Cory Tomas Doran Yuval Kogman Watson Dagfinn Ilmari Mannsåker
+Dan Brook David
 
 =head1 NAME
 
@@ -38,7 +37,7 @@ MooseX::Storage::IO::AtomicFile - An Atomic File I/O role
 
 =head1 VERSION
 
-version 0.44
+version 0.46
 
 =head1 SYNOPSIS
 
