@@ -1,14 +1,12 @@
 package MooseX::Storage::IO::File;
-{
-  $MooseX::Storage::IO::File::VERSION = '0.44';
-}
 BEGIN {
   $MooseX::Storage::IO::File::AUTHORITY = 'cpan:STEVAN';
 }
 # ABSTRACT: A basic File I/O role
+$MooseX::Storage::IO::File::VERSION = '0.46';
 use Moose::Role;
-
 use MooseX::Storage::Engine::IO::File;
+use namespace::autoclean;
 
 requires 'thaw';
 requires 'freeze';
@@ -34,7 +32,10 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc.
+Interactive, Inc. Golden Steinbrunner Florian Ragwitz Johannes Plunien
+Jonathan Rockway Yu Jos Boumans Karen Etheridge Ricardo Signes Robert Boone
+Shawn M Moore Cory Tomas Doran Yuval Kogman Watson Dagfinn Ilmari Mannsåker
+Dan Brook David
 
 =head1 NAME
 
@@ -42,7 +43,7 @@ MooseX::Storage::IO::File - A basic File I/O role
 
 =head1 VERSION
 
-version 0.44
+version 0.46
 
 =head1 SYNOPSIS
 
