@@ -1,12 +1,11 @@
 package MooseX::Storage::Traits::OnlyWhenBuilt;
-{
-  $MooseX::Storage::Traits::OnlyWhenBuilt::VERSION = '0.44';
-}
 BEGIN {
   $MooseX::Storage::Traits::OnlyWhenBuilt::AUTHORITY = 'cpan:STEVAN';
 }
 # ABSTRACT: A custom trait to bypass serialization
+$MooseX::Storage::Traits::OnlyWhenBuilt::VERSION = '0.46';
 use Moose::Role;
+use namespace::autoclean;
 
 requires 'pack';
 requires 'unpack';
@@ -36,7 +35,10 @@ __END__
 =encoding UTF-8
 
 =for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. culted
+Interactive, Inc. Golden Steinbrunner Florian Ragwitz Johannes Plunien
+Jonathan Rockway Yu Jos Boumans Karen Etheridge Ricardo Signes Robert Boone
+Shawn M Moore Cory Tomas Doran Yuval Kogman Watson Dagfinn Ilmari Mannsåker
+Dan Brook David culted
 
 =head1 NAME
 
@@ -44,7 +46,7 @@ MooseX::Storage::Traits::OnlyWhenBuilt - A custom trait to bypass serialization
 
 =head1 VERSION
 
-version 0.44
+version 0.46
 
 =head1 SYNOPSIS
 
